@@ -45,14 +45,14 @@ def arg_parse(config_file):
             exit(1)
 
         temp_dir = tempfile.mkdtemp()
-        version_dir_to_upload= os.path.join(upload_file_path, version_name)
+        # version_dir_to_upload= os.path.join(upload_file_path, version_name)
         zipped_file_path = os.path.join(temp_dir, version_name + '.zip')
 
-        print('version_dir_to_upload: ', version_dir_to_upload)
-        print('zipped_file_path: ', zipped_file_path)
-        
+        # print('version_dir_to_upload: ', version_dir_to_upload)
+        # print('zipped_file_path: ', zipped_file_path)
+
         # second param was version_name
-        create_zip(zipped_file_path, version_dir_to_upload)
+        create_zip(zipped_file_path, upload_file_path, version_name)
         with open(config_file, "r") as stream:
             try:
                 config = yaml.safe_load(stream)
