@@ -1,4 +1,5 @@
 import requests
+import logging
 
 def get_bearer_token(config):
     email_add = config['robin_email']
@@ -14,8 +15,8 @@ def get_bearer_token(config):
 
     if response.status_code == 200:
         bearer_token = response.json()['token']
-        print ("Bearer token: " + bearer_token)
+        logging.info("Bearer token: " + bearer_token)
         return bearer_token
     else:
-        print("Error getting bearer token")
+        logging.error("Error getting bearer token")
         return 1
